
C     **************************************************
C     *  getPlumeFracRemaining.f                       *
C     **************************************************

C     WRITTEN BY Geoff Stuart, Robin Stevens, Jeff Pierce, April 2013

C     This subroutine calculates the number fraction of particles remaining
C     after initial fast coagulation in plumes.  The designed intention of
C     This parameterization is for sea-salt particles emitted from ships in
C     Geoengineering simulations; however, the parameterization should work
C     for other near-source coagulation of aerosols.

C     The input parameters and their tested ranges are described in the
C     "INPUTS" section.  The subroutine gives sensible results for the
C     fraction remaining outside of the tested ranges (all FRs are between
C     0 and 1), but we have not tested these values.

C     The subroutine is described in detail the accomaning paper
C     Stuart, G. S., Stevens, R. G., Partanen, A.-I., Jenkins, A. K. L.,
C     Korhonen, H., Forster, P. M., Spracklen, D. V., and Pierce, J. R.:
C     Reduced efficacy of marine cloud brightening geoengineering due to
C     in-plume aerosol coagulation: parameterization and global implications,
C     Atmos. Chem. Phys. Discuss., 13, 18679-18711,
C     doi:10.5194/acpd-13-18679-2013, 2013.

      SUBROUTINE getPlumeFracRemaining(Vw,P,Dp,sigma,Rs,s,FR,Dpf)

      implicit none

C-----INPUTS------------------------------------------------------------

      double precision Vw     ! Wind speed [m/s]
                              ! Tested range: 4-20 m/s
      double precision P      ! Particle emission rate [#/s]
                              ! Tested range: 1.1E16-1.1E18 #/s
      double precision Dp     ! Emissions median dry diameter [nm]
                              ! Tested range: 100-400 nm
      double precision sigma  ! Geometric standard deviation of emissions
                              ! Tested range: 1 (mondisperse) - 2
      double precision Rs     ! Emissions stack radius [m]
                              ! Tested range: 0.6-2.4 [m]
      integer s               ! Pasquill Stability class
                              ! For A, Extremely unstable, pass "1"
                              ! For B, Moderately unstable, pass "2"
                              ! For C, Slightly unstable, pass "3"
                              ! For D, Neutral, pass "4"
                              ! For E, Slightly stable, pass "5"
                              ! For F, Moderately stable, pass "6"

C-----OUTPUTS-----------------------------------------------------------

      double precision FR     ! Fraction of the initial number of 
                              ! particles that remain
      double precision Dpf    ! The final median dry diameter due to growth by
                              ! coagulation (assumes that sigma is constant)

C-----VARIABLE DECLARATIONS---------------------------------------------

      integer nstab
      parameter (nstab=6) ! number of stability classes
      double precision Vwo
      parameter (Vwo=8.d0) ! base value of Wind speed [m/s]
      double precision Po
      parameter (Po=1.1d17) ! base value of number emissions [1/s]
      double precision Dpo
      parameter (Dpo=200.d0) ! base value of median dry diameter [nm]
      double precision sigmao
      parameter (sigmao=1.2d0) ! base value of standard deviation
      double precision Rso
      parameter (Rso=1.2d0) ! base value of stack radius [m]
      double precision eVw(nstab) ! exponent for wind speed
      data eVw /-0.84, -0.96, -1.17, -1.28, -1.34, -1.41/
      double precision eP(nstab) ! exponent for number emissions
      data eP /0.51, 0.56, 0.65, 0.69, 0.72, 0.76/
      double precision eDp(nstab) ! exponent for median dry diameter
      data eDp /-0.13, -0.14, -0.16, -0.17, -0.18, -0.18/
      double precision esigma(nstab) ! exponent for standard deviation
      data esigma /0.30, 0.33, 0.37, 0.38, 0.38, 0.37/
      double precision eRs(nstab) ! exponent for stack radius
      data eRs /-0.40, -0.39, -0.36, -0.30, -0.23, -0.13/
      double precision k(nstab) ! additional fit parameter
      data k /1.282, 1.219, 0.969, 0.774, 0.611, 0.363/

C-----CODE--------------------------------------------------------------

      FR = k(s) / ( (Vw/Vwo)**eVw(s) * (P/Po)**eP(s)
     &     * (Dp/Dpo)**eDp(s) * (sigma/sigmao)**esigma(s) 
     &     * (Rs/Rso)**eRs(s) + k(s) ) ! Eqn. 5 in paper
      
      Dpf = ( Dp**(3.d0) / FR ) ** (1.d0/3.d0)

      RETURN
      END
